from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TDF import *
from OCC.Core.TDataStd import *
from OCC.Core.gp import *
from OCC.Core.TNaming import *
from OCC.Core.Quantity import *
from OCC.Core.TopoDS import *
from OCC.Core.Poly import *
from OCC.Core.TShort import *


class TDataXtd_Array1OfTrsf:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> gp_Trsf: ...
    def __setitem__(self, index: int, value: gp_Trsf) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[gp_Trsf]: ...
    def next(self) -> gp_Trsf: ...
    __next__ = next
    def Init(self, theValue: gp_Trsf) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> gp_Trsf: ...
    def Last(self) -> gp_Trsf: ...
    def Value(self, theIndex: int) -> gp_Trsf: ...
    def SetValue(self, theIndex: int, theValue: gp_Trsf) -> None: ...

class TDataXtd_ConstraintEnum(IntEnum):
	TDataXtd_RADIUS: int = ...
	TDataXtd_DIAMETER: int = ...
	TDataXtd_MINOR_RADIUS: int = ...
	TDataXtd_MAJOR_RADIUS: int = ...
	TDataXtd_TANGENT: int = ...
	TDataXtd_PARALLEL: int = ...
	TDataXtd_PERPENDICULAR: int = ...
	TDataXtd_CONCENTRIC: int = ...
	TDataXtd_COINCIDENT: int = ...
	TDataXtd_DISTANCE: int = ...
	TDataXtd_ANGLE: int = ...
	TDataXtd_EQUAL_RADIUS: int = ...
	TDataXtd_SYMMETRY: int = ...
	TDataXtd_MIDPOINT: int = ...
	TDataXtd_EQUAL_DISTANCE: int = ...
	TDataXtd_FIX: int = ...
	TDataXtd_RIGID: int = ...
	TDataXtd_FROM: int = ...
	TDataXtd_AXIS: int = ...
	TDataXtd_MATE: int = ...
	TDataXtd_ALIGN_FACES: int = ...
	TDataXtd_ALIGN_AXES: int = ...
	TDataXtd_AXES_ANGLE: int = ...
	TDataXtd_FACES_ANGLE: int = ...
	TDataXtd_ROUND: int = ...
	TDataXtd_OFFSET: int = ...
TDataXtd_RADIUS = TDataXtd_ConstraintEnum.TDataXtd_RADIUS
TDataXtd_DIAMETER = TDataXtd_ConstraintEnum.TDataXtd_DIAMETER
TDataXtd_MINOR_RADIUS = TDataXtd_ConstraintEnum.TDataXtd_MINOR_RADIUS
TDataXtd_MAJOR_RADIUS = TDataXtd_ConstraintEnum.TDataXtd_MAJOR_RADIUS
TDataXtd_TANGENT = TDataXtd_ConstraintEnum.TDataXtd_TANGENT
TDataXtd_PARALLEL = TDataXtd_ConstraintEnum.TDataXtd_PARALLEL
TDataXtd_PERPENDICULAR = TDataXtd_ConstraintEnum.TDataXtd_PERPENDICULAR
TDataXtd_CONCENTRIC = TDataXtd_ConstraintEnum.TDataXtd_CONCENTRIC
TDataXtd_COINCIDENT = TDataXtd_ConstraintEnum.TDataXtd_COINCIDENT
TDataXtd_DISTANCE = TDataXtd_ConstraintEnum.TDataXtd_DISTANCE
TDataXtd_ANGLE = TDataXtd_ConstraintEnum.TDataXtd_ANGLE
TDataXtd_EQUAL_RADIUS = TDataXtd_ConstraintEnum.TDataXtd_EQUAL_RADIUS
TDataXtd_SYMMETRY = TDataXtd_ConstraintEnum.TDataXtd_SYMMETRY
TDataXtd_MIDPOINT = TDataXtd_ConstraintEnum.TDataXtd_MIDPOINT
TDataXtd_EQUAL_DISTANCE = TDataXtd_ConstraintEnum.TDataXtd_EQUAL_DISTANCE
TDataXtd_FIX = TDataXtd_ConstraintEnum.TDataXtd_FIX
TDataXtd_RIGID = TDataXtd_ConstraintEnum.TDataXtd_RIGID
TDataXtd_FROM = TDataXtd_ConstraintEnum.TDataXtd_FROM
TDataXtd_AXIS = TDataXtd_ConstraintEnum.TDataXtd_AXIS
TDataXtd_MATE = TDataXtd_ConstraintEnum.TDataXtd_MATE
TDataXtd_ALIGN_FACES = TDataXtd_ConstraintEnum.TDataXtd_ALIGN_FACES
TDataXtd_ALIGN_AXES = TDataXtd_ConstraintEnum.TDataXtd_ALIGN_AXES
TDataXtd_AXES_ANGLE = TDataXtd_ConstraintEnum.TDataXtd_AXES_ANGLE
TDataXtd_FACES_ANGLE = TDataXtd_ConstraintEnum.TDataXtd_FACES_ANGLE
TDataXtd_ROUND = TDataXtd_ConstraintEnum.TDataXtd_ROUND
TDataXtd_OFFSET = TDataXtd_ConstraintEnum.TDataXtd_OFFSET

class TDataXtd_GeometryEnum(IntEnum):
	TDataXtd_ANY_GEOM: int = ...
	TDataXtd_POINT: int = ...
	TDataXtd_LINE: int = ...
	TDataXtd_CIRCLE: int = ...
	TDataXtd_ELLIPSE: int = ...
	TDataXtd_SPLINE: int = ...
	TDataXtd_PLANE: int = ...
	TDataXtd_CYLINDER: int = ...
TDataXtd_ANY_GEOM = TDataXtd_GeometryEnum.TDataXtd_ANY_GEOM
TDataXtd_POINT = TDataXtd_GeometryEnum.TDataXtd_POINT
TDataXtd_LINE = TDataXtd_GeometryEnum.TDataXtd_LINE
TDataXtd_CIRCLE = TDataXtd_GeometryEnum.TDataXtd_CIRCLE
TDataXtd_ELLIPSE = TDataXtd_GeometryEnum.TDataXtd_ELLIPSE
TDataXtd_SPLINE = TDataXtd_GeometryEnum.TDataXtd_SPLINE
TDataXtd_PLANE = TDataXtd_GeometryEnum.TDataXtd_PLANE
TDataXtd_CYLINDER = TDataXtd_GeometryEnum.TDataXtd_CYLINDER

class tdataxtd:
	@staticmethod
	def IDList(anIDList: TDF_IDList) -> None: ...

class TDataXtd_Axis(TDataStd_GenericEmpty):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataXtd_Axis: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, L: gp_Lin) -> TDataXtd_Axis: ...

class TDataXtd_Constraint(TDF_Attribute):
	def __init__(self) -> None: ...
	def ClearGeometries(self) -> None: ...
	@staticmethod
	def CollectChildConstraints(aLabel: TDF_Label, TheList: TDF_LabelList) -> None: ...
	def GetGeometry(self, Index: int) -> TNaming_NamedShape: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetPlane(self) -> TNaming_NamedShape: ...
	def GetType(self) -> TDataXtd_ConstraintEnum: ...
	def GetValue(self) -> TDataStd_Real: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	def Inverted(self, status: bool) -> None: ...
	@overload
	def Inverted(self) -> bool: ...
	def IsDimension(self) -> bool: ...
	def IsPlanar(self) -> bool: ...
	def NbGeometries(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def References(self, DS: TDF_DataSet) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@overload
	def Reversed(self, status: bool) -> None: ...
	@overload
	def Reversed(self) -> bool: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataXtd_Constraint: ...
	@overload
	def Set(self, type: TDataXtd_ConstraintEnum, G1: TNaming_NamedShape) -> None: ...
	@overload
	def Set(self, type: TDataXtd_ConstraintEnum, G1: TNaming_NamedShape, G2: TNaming_NamedShape) -> None: ...
	@overload
	def Set(self, type: TDataXtd_ConstraintEnum, G1: TNaming_NamedShape, G2: TNaming_NamedShape, G3: TNaming_NamedShape) -> None: ...
	@overload
	def Set(self, type: TDataXtd_ConstraintEnum, G1: TNaming_NamedShape, G2: TNaming_NamedShape, G3: TNaming_NamedShape, G4: TNaming_NamedShape) -> None: ...
	def SetGeometry(self, Index: int, G: TNaming_NamedShape) -> None: ...
	def SetPlane(self, plane: TNaming_NamedShape) -> None: ...
	def SetType(self, CTR: TDataXtd_ConstraintEnum) -> None: ...
	def SetValue(self, V: TDataStd_Real) -> None: ...
	@overload
	def Verified(self) -> bool: ...
	@overload
	def Verified(self, status: bool) -> None: ...

class TDataXtd_Geometry(TDF_Attribute):
	def __init__(self) -> None: ...
	@overload
	@staticmethod
	def Axis(L: TDF_Label, G: gp_Ax1) -> bool: ...
	@overload
	@staticmethod
	def Axis(S: TNaming_NamedShape, G: gp_Ax1) -> bool: ...
	@overload
	@staticmethod
	def Circle(L: TDF_Label, G: gp_Circ) -> bool: ...
	@overload
	@staticmethod
	def Circle(S: TNaming_NamedShape, G: gp_Circ) -> bool: ...
	@overload
	@staticmethod
	def Cylinder(L: TDF_Label, G: gp_Cylinder) -> bool: ...
	@overload
	@staticmethod
	def Cylinder(S: TNaming_NamedShape, G: gp_Cylinder) -> bool: ...
	@overload
	@staticmethod
	def Ellipse(L: TDF_Label, G: gp_Elips) -> bool: ...
	@overload
	@staticmethod
	def Ellipse(S: TNaming_NamedShape, G: gp_Elips) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetType(self) -> TDataXtd_GeometryEnum: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	@staticmethod
	def Line(L: TDF_Label, G: gp_Lin) -> bool: ...
	@overload
	@staticmethod
	def Line(S: TNaming_NamedShape, G: gp_Lin) -> bool: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	@overload
	@staticmethod
	def Plane(L: TDF_Label, G: gp_Pln) -> bool: ...
	@overload
	@staticmethod
	def Plane(S: TNaming_NamedShape, G: gp_Pln) -> bool: ...
	@overload
	@staticmethod
	def Point(L: TDF_Label, G: gp_Pnt) -> bool: ...
	@overload
	@staticmethod
	def Point(S: TNaming_NamedShape, G: gp_Pnt) -> bool: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(label: TDF_Label) -> TDataXtd_Geometry: ...
	def SetType(self, T: TDataXtd_GeometryEnum) -> None: ...
	@overload
	@staticmethod
	def Type(L: TDF_Label) -> TDataXtd_GeometryEnum: ...
	@overload
	@staticmethod
	def Type(S: TNaming_NamedShape) -> TDataXtd_GeometryEnum: ...

class TDataXtd_Pattern(TDF_Attribute):
	def ComputeTrsfs(self, Trsfs: TDataXtd_Array1OfTrsf) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def NbTrsfs(self) -> int: ...
	def PatternID(self) -> Standard_GUID: ...

class TDataXtd_Placement(TDataStd_GenericEmpty):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@staticmethod
	def Set(label: TDF_Label) -> TDataXtd_Placement: ...

class TDataXtd_Plane(TDataStd_GenericEmpty):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataXtd_Plane: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, P: gp_Pln) -> TDataXtd_Plane: ...

class TDataXtd_Point(TDataStd_GenericEmpty):
	def __init__(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label) -> TDataXtd_Point: ...
	@overload
	@staticmethod
	def Set(label: TDF_Label, P: gp_Pnt) -> TDataXtd_Point: ...

class TDataXtd_Position(TDF_Attribute):
	def __init__(self) -> None: ...
	@staticmethod
	def Get(aLabel: TDF_Label, aPos: gp_Pnt) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetPosition(self) -> gp_Pnt: ...
	def ID(self) -> Standard_GUID: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, intoAttribute: TDF_Attribute, aRelocTationable: TDF_RelocationTable) -> None: ...
	def Restore(self, anAttribute: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(aLabel: TDF_Label, aPos: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def Set(aLabel: TDF_Label) -> TDataXtd_Position: ...
	def SetPosition(self, aPos: gp_Pnt) -> None: ...

class TDataXtd_Presentation(TDF_Attribute):
	def __init__(self) -> None: ...
	def AddSelectionMode(self, theSelectionMode: int, theTransaction: Optional[bool] = True) -> None: ...
	def BackupCopy(self) -> TDF_Attribute: ...
	def Color(self) -> Quantity_NameOfColor: ...
	def GetDriverGUID(self) -> Standard_GUID: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetNbSelectionModes(self) -> int: ...
	def HasOwnColor(self) -> bool: ...
	def HasOwnMaterial(self) -> bool: ...
	def HasOwnMode(self) -> bool: ...
	def HasOwnSelectionMode(self) -> bool: ...
	def HasOwnTransparency(self) -> bool: ...
	def HasOwnWidth(self) -> bool: ...
	def ID(self) -> Standard_GUID: ...
	def IsDisplayed(self) -> bool: ...
	def MaterialIndex(self) -> int: ...
	def Mode(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, intoAttribute: TDF_Attribute, aRelocTationable: TDF_RelocationTable) -> None: ...
	def Restore(self, anAttribute: TDF_Attribute) -> None: ...
	def SelectionMode(self, index: Optional[int] = 1) -> int: ...
	@staticmethod
	def Set(theLabel: TDF_Label, theDriverId: Standard_GUID) -> TDataXtd_Presentation: ...
	def SetColor(self, theColor: Quantity_NameOfColor) -> None: ...
	def SetDisplayed(self, theIsDisplayed: bool) -> None: ...
	def SetDriverGUID(self, theGUID: Standard_GUID) -> None: ...
	def SetMaterialIndex(self, theMaterialIndex: int) -> None: ...
	def SetMode(self, theMode: int) -> None: ...
	def SetSelectionMode(self, theSelectionMode: int, theTransaction: Optional[bool] = True) -> None: ...
	def SetTransparency(self, theValue: float) -> None: ...
	def SetWidth(self, theWidth: float) -> None: ...
	def Transparency(self) -> float: ...
	@staticmethod
	def Unset(theLabel: TDF_Label) -> None: ...
	def UnsetColor(self) -> None: ...
	def UnsetMaterial(self) -> None: ...
	def UnsetMode(self) -> None: ...
	def UnsetSelectionMode(self) -> None: ...
	def UnsetTransparency(self) -> None: ...
	def UnsetWidth(self) -> None: ...
	def Width(self) -> float: ...
	@staticmethod
	def getColorNameFromOldEnum(theOld: int) -> Quantity_NameOfColor: ...
	@staticmethod
	def getOldColorNameFromNewEnum(theNew: Quantity_NameOfColor) -> int: ...

class TDataXtd_Shape(TDataStd_GenericEmpty):
	def __init__(self) -> None: ...
	@staticmethod
	def Find(current: TDF_Label, S: TDataXtd_Shape) -> bool: ...
	@staticmethod
	def Get(label: TDF_Label) -> TopoDS_Shape: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	@staticmethod
	def New(label: TDF_Label) -> TDataXtd_Shape: ...
	def References(self, DS: TDF_DataSet) -> None: ...
	@staticmethod
	def Set(label: TDF_Label, shape: TopoDS_Shape) -> TDataXtd_Shape: ...

class TDataXtd_Triangulation(TDF_Attribute):
	def __init__(self) -> None: ...
	@overload
	def Deflection(self) -> float: ...
	@overload
	def Deflection(self, theDeflection: float) -> None: ...
	def Get(self) -> Poly_Triangulation: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def HasNormals(self) -> bool: ...
	def HasUVNodes(self) -> bool: ...
	def ID(self) -> Standard_GUID: ...
	def NbNodes(self) -> int: ...
	def NbTriangles(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Node(self, theIndex: int) -> gp_Pnt: ...
	def Normal(self, theIndex: int) -> gp_Dir: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def RemoveUVNodes(self) -> None: ...
	def Restore(self, theAttribute: TDF_Attribute) -> None: ...
	@overload
	@staticmethod
	def Set(theLabel: TDF_Label) -> TDataXtd_Triangulation: ...
	@overload
	@staticmethod
	def Set(theLabel: TDF_Label, theTriangulation: Poly_Triangulation) -> TDataXtd_Triangulation: ...
	@overload
	def Set(self, theTriangulation: Poly_Triangulation) -> None: ...
	def SetNode(self, theIndex: int, theNode: gp_Pnt) -> None: ...
	def SetNormal(self, theIndex: int, theNormal: gp_Dir) -> None: ...
	def SetNormals(self, theNormals: TShort_HArray1OfShortReal) -> None: ...
	def SetTriangle(self, theIndex: int, theTriangle: Poly_Triangle) -> None: ...
	def SetUVNode(self, theIndex: int, theUVNode: gp_Pnt2d) -> None: ...
	def Triangle(self, theIndex: int) -> Poly_Triangle: ...
	def UVNode(self, theIndex: int) -> gp_Pnt2d: ...

class TDataXtd_PatternStd(TDataXtd_Pattern):
	def __init__(self) -> None: ...
	@overload
	def Axis1(self, Axis1: TNaming_NamedShape) -> None: ...
	@overload
	def Axis1(self) -> TNaming_NamedShape: ...
	@overload
	def Axis1Reversed(self, Axis1Reversed: bool) -> None: ...
	@overload
	def Axis1Reversed(self) -> bool: ...
	@overload
	def Axis2(self, Axis2: TNaming_NamedShape) -> None: ...
	@overload
	def Axis2(self) -> TNaming_NamedShape: ...
	@overload
	def Axis2Reversed(self, Axis2Reversed: bool) -> None: ...
	@overload
	def Axis2Reversed(self) -> bool: ...
	def ComputeTrsfs(self, Trsfs: TDataXtd_Array1OfTrsf) -> None: ...
	@staticmethod
	def GetPatternID() -> Standard_GUID: ...
	@overload
	def Mirror(self, plane: TNaming_NamedShape) -> None: ...
	@overload
	def Mirror(self) -> TNaming_NamedShape: ...
	@overload
	def NbInstances1(self, NbInstances1: TDataStd_Integer) -> None: ...
	@overload
	def NbInstances1(self) -> TDataStd_Integer: ...
	@overload
	def NbInstances2(self, NbInstances2: TDataStd_Integer) -> None: ...
	@overload
	def NbInstances2(self) -> TDataStd_Integer: ...
	def NbTrsfs(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def PatternID(self) -> Standard_GUID: ...
	def References(self, aDataSet: TDF_DataSet) -> None: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	@staticmethod
	def Set(label: TDF_Label) -> TDataXtd_PatternStd: ...
	@overload
	def Signature(self, signature: int) -> None: ...
	@overload
	def Signature(self) -> int: ...
	@overload
	def Value1(self, value: TDataStd_Real) -> None: ...
	@overload
	def Value1(self) -> TDataStd_Real: ...
	@overload
	def Value2(self, value: TDataStd_Real) -> None: ...
	@overload
	def Value2(self) -> TDataStd_Real: ...

# harray1 classes

class TDataXtd_HArray1OfTrsf(TDataXtd_Array1OfTrsf, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TDataXtd_Array1OfTrsf: ...

# harray2 classes
# hsequence classes

tdataxtd_IDList = tdataxtd.IDList
tdataxtd_Print = tdataxtd.Print
tdataxtd_Print = tdataxtd.Print
TDataXtd_Axis_GetID = TDataXtd_Axis.GetID
TDataXtd_Axis_Set = TDataXtd_Axis.Set
TDataXtd_Axis_Set = TDataXtd_Axis.Set
TDataXtd_Constraint_CollectChildConstraints = TDataXtd_Constraint.CollectChildConstraints
TDataXtd_Constraint_GetID = TDataXtd_Constraint.GetID
TDataXtd_Constraint_Set = TDataXtd_Constraint.Set
TDataXtd_Geometry_Axis = TDataXtd_Geometry.Axis
TDataXtd_Geometry_Axis = TDataXtd_Geometry.Axis
TDataXtd_Geometry_Circle = TDataXtd_Geometry.Circle
TDataXtd_Geometry_Circle = TDataXtd_Geometry.Circle
TDataXtd_Geometry_Cylinder = TDataXtd_Geometry.Cylinder
TDataXtd_Geometry_Cylinder = TDataXtd_Geometry.Cylinder
TDataXtd_Geometry_Ellipse = TDataXtd_Geometry.Ellipse
TDataXtd_Geometry_Ellipse = TDataXtd_Geometry.Ellipse
TDataXtd_Geometry_GetID = TDataXtd_Geometry.GetID
TDataXtd_Geometry_Line = TDataXtd_Geometry.Line
TDataXtd_Geometry_Line = TDataXtd_Geometry.Line
TDataXtd_Geometry_Plane = TDataXtd_Geometry.Plane
TDataXtd_Geometry_Plane = TDataXtd_Geometry.Plane
TDataXtd_Geometry_Point = TDataXtd_Geometry.Point
TDataXtd_Geometry_Point = TDataXtd_Geometry.Point
TDataXtd_Geometry_Set = TDataXtd_Geometry.Set
TDataXtd_Geometry_Type = TDataXtd_Geometry.Type
TDataXtd_Geometry_Type = TDataXtd_Geometry.Type
TDataXtd_Pattern_GetID = TDataXtd_Pattern.GetID
TDataXtd_Placement_GetID = TDataXtd_Placement.GetID
TDataXtd_Placement_Set = TDataXtd_Placement.Set
TDataXtd_Plane_GetID = TDataXtd_Plane.GetID
TDataXtd_Plane_Set = TDataXtd_Plane.Set
TDataXtd_Plane_Set = TDataXtd_Plane.Set
TDataXtd_Point_GetID = TDataXtd_Point.GetID
TDataXtd_Point_Set = TDataXtd_Point.Set
TDataXtd_Point_Set = TDataXtd_Point.Set
TDataXtd_Position_Get = TDataXtd_Position.Get
TDataXtd_Position_GetID = TDataXtd_Position.GetID
TDataXtd_Position_Set = TDataXtd_Position.Set
TDataXtd_Position_Set = TDataXtd_Position.Set
TDataXtd_Presentation_GetID = TDataXtd_Presentation.GetID
TDataXtd_Presentation_Set = TDataXtd_Presentation.Set
TDataXtd_Presentation_Unset = TDataXtd_Presentation.Unset
TDataXtd_Presentation_getColorNameFromOldEnum = TDataXtd_Presentation.getColorNameFromOldEnum
TDataXtd_Presentation_getOldColorNameFromNewEnum = TDataXtd_Presentation.getOldColorNameFromNewEnum
TDataXtd_Shape_Find = TDataXtd_Shape.Find
TDataXtd_Shape_Get = TDataXtd_Shape.Get
TDataXtd_Shape_GetID = TDataXtd_Shape.GetID
TDataXtd_Shape_New = TDataXtd_Shape.New
TDataXtd_Shape_Set = TDataXtd_Shape.Set
TDataXtd_Triangulation_GetID = TDataXtd_Triangulation.GetID
TDataXtd_Triangulation_Set = TDataXtd_Triangulation.Set
TDataXtd_Triangulation_Set = TDataXtd_Triangulation.Set
TDataXtd_PatternStd_GetPatternID = TDataXtd_PatternStd.GetPatternID
TDataXtd_PatternStd_Set = TDataXtd_PatternStd.Set



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
CPnts module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_cpnts.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CPnts
else:
    import _CPnts

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _CPnts.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _CPnts.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _CPnts.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _CPnts.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _CPnts.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _CPnts.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _CPnts.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _CPnts.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _CPnts.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _CPnts.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _CPnts.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _CPnts.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _CPnts.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _CPnts.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _CPnts.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _CPnts.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _CPnts.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _CPnts:
_CPnts.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _CPnts.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *



class CPnts_AbscissaPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>. <resolution> is the error allowed in the computation. the computed point can be outside of the curve 's bounds.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        U0: float
        Resolution: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>. <resolution> is the error allowed in the computation. the computed point can be outside of the curve 's bounds.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        U0: float
        Resolution: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>. <ui> is the starting value used in the iterative process which find the solution, it must be closed to the final solution <resolution> is the error allowed in the computation. the computed point can be outside of the curve 's bounds.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        U0: float
        Ui: float
        Resolution: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>. <ui> is the starting value used in the iterative process which find the solution, it must be closed to the final solution <resolution> is the error allowed in the computation. the computed point can be outside of the curve 's bounds.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        U0: float
        Ui: float
        Resolution: float

        Returns
        -------
        None

        """
        _CPnts.CPnts_AbscissaPoint_swiginit(self, _CPnts.new_CPnts_AbscissaPoint(*args))

    def AdvPerform(self, *args) -> "void":
        r"""
        Computes the point at the distance <abscissa> of the curve; performs more appropriate tolerance managment; to use this method in right way it is necessary to call empty consructor. then call method init with tolerance = resolution, then call advpermorm. u0 is the parameter of the point from which the distance is measured and ui is the starting value for the iterative process (should be close to the final solution).

        Parameters
        ----------
        Abscissa: float
        U0: float
        Ui: float
        Resolution: float

        Returns
        -------
        None

        """
        return _CPnts.CPnts_AbscissaPoint_AdvPerform(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes the resolution function with <c>.

        Parameters
        ----------
        C: Adaptor3d_Curve

        Returns
        -------
        None
        Initializes the resolution function with <c>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d

        Returns
        -------
        None
        Initializes the resolution function with <c>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Tol: float

        Returns
        -------
        None
        Initializes the resolution function with <c>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Tol: float

        Returns
        -------
        None
        Initializes the resolution function with <c> between u1 and u2.

        Parameters
        ----------
        C: Adaptor3d_Curve
        U1: float
        U2: float

        Returns
        -------
        None
        Initializes the resolution function with <c> between u1 and u2.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        U1: float
        U2: float

        Returns
        -------
        None
        Initializes the resolution function with <c> between u1 and u2.

        Parameters
        ----------
        C: Adaptor3d_Curve
        U1: float
        U2: float
        Tol: float

        Returns
        -------
        None
        Initializes the resolution function with <c> between u1 and u2.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        U1: float
        U2: float
        Tol: float

        Returns
        -------
        None

        """
        return _CPnts.CPnts_AbscissaPoint_Init(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        True if the computation was successful, false otherwise.

        Returns
        -------
        bool

        """
        return _CPnts.CPnts_AbscissaPoint_IsDone(self, *args)

    @staticmethod
    def Length(*args) -> "Standard_Real":
        r"""
        Computes the length of the curve <c>.

        Parameters
        ----------
        C: Adaptor3d_Curve

        Returns
        -------
        float
        Computes the length of the curve <c>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d

        Returns
        -------
        float
        Computes the length of the curve <c> with the given tolerance.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Tol: float

        Returns
        -------
        float
        Computes the length of the curve <c> with the given tolerance.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Tol: float

        Returns
        -------
        float
        Computes the length of the curve <c> between <u1> and <u2>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        U1: float
        U2: float

        Returns
        -------
        float
        Computes the length of the curve <c> between <u1> and <u2>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        U1: float
        U2: float

        Returns
        -------
        float
        Computes the length of the curve <c> between <u1> and <u2> with the given tolerance.

        Parameters
        ----------
        C: Adaptor3d_Curve
        U1: float
        U2: float
        Tol: float

        Returns
        -------
        float
        Computes the length of the curve <c> between <u1> and <u2> with the given tolerance. creation of a indefinite abscissapoint.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        U1: float
        U2: float
        Tol: float

        Returns
        -------
        float

        """
        return _CPnts.CPnts_AbscissaPoint_Length(*args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the solution.

        Returns
        -------
        float

        """
        return _CPnts.CPnts_AbscissaPoint_Parameter(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Computes the point at the distance <abscissa> of the curve. u0 is the parameter of the point from which the distance is measured.

        Parameters
        ----------
        Abscissa: float
        U0: float
        Resolution: float

        Returns
        -------
        None
        Computes the point at the distance <abscissa> of the curve. u0 is the parameter of the point from which the distance is measured and ui is the starting value for the iterative process (should be close to the final solution).

        Parameters
        ----------
        Abscissa: float
        U0: float
        Ui: float
        Resolution: float

        Returns
        -------
        None

        """
        return _CPnts.CPnts_AbscissaPoint_Perform(self, *args)

    def SetParameter(self, *args) -> "void":
        r"""
        Enforce the solution, used by gcpnts.

        Parameters
        ----------
        P: float

        Returns
        -------
        None

        """
        return _CPnts.CPnts_AbscissaPoint_SetParameter(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _CPnts.delete_CPnts_AbscissaPoint

# Register CPnts_AbscissaPoint in _CPnts:
_CPnts.CPnts_AbscissaPoint_swigregister(CPnts_AbscissaPoint)

def CPnts_AbscissaPoint_Length(*args) -> "Standard_Real":
    r"""
    Computes the length of the curve <c>.

    Parameters
    ----------
    C: Adaptor3d_Curve

    Returns
    -------
    float
    Computes the length of the curve <c>.

    Parameters
    ----------
    C: Adaptor2d_Curve2d

    Returns
    -------
    float
    Computes the length of the curve <c> with the given tolerance.

    Parameters
    ----------
    C: Adaptor3d_Curve
    Tol: float

    Returns
    -------
    float
    Computes the length of the curve <c> with the given tolerance.

    Parameters
    ----------
    C: Adaptor2d_Curve2d
    Tol: float

    Returns
    -------
    float
    Computes the length of the curve <c> between <u1> and <u2>.

    Parameters
    ----------
    C: Adaptor3d_Curve
    U1: float
    U2: float

    Returns
    -------
    float
    Computes the length of the curve <c> between <u1> and <u2>.

    Parameters
    ----------
    C: Adaptor2d_Curve2d
    U1: float
    U2: float

    Returns
    -------
    float
    Computes the length of the curve <c> between <u1> and <u2> with the given tolerance.

    Parameters
    ----------
    C: Adaptor3d_Curve
    U1: float
    U2: float
    Tol: float

    Returns
    -------
    float
    Computes the length of the curve <c> between <u1> and <u2> with the given tolerance. creation of a indefinite abscissapoint.

    Parameters
    ----------
    C: Adaptor2d_Curve2d
    U1: float
    U2: float
    Tol: float

    Returns
    -------
    float

    """
    return _CPnts.CPnts_AbscissaPoint_Length(*args)

class CPnts_MyGaussFunction(OCC.Core.math.math_Function):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _CPnts.CPnts_MyGaussFunction_swiginit(self, _CPnts.new_CPnts_MyGaussFunction(*args))

    def Init(self, *args) -> "void":
        r"""
        F is a pointer on a function d is a client data //! each value is computed with f(d).

        Parameters
        ----------
        F: CPnts_RealFunction
        D: Standard_Address

        Returns
        -------
        None

        """
        return _CPnts.CPnts_MyGaussFunction_Init(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _CPnts.delete_CPnts_MyGaussFunction

# Register CPnts_MyGaussFunction in _CPnts:
_CPnts.CPnts_MyGaussFunction_swigregister(CPnts_MyGaussFunction)

class CPnts_MyRootFunction(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _CPnts.CPnts_MyRootFunction_swiginit(self, _CPnts.new_CPnts_MyRootFunction(*args))

    def Init(self, *args) -> "void":
        r"""
        F is a pointer on a function d is a client data order is the order of integration to use.

        Parameters
        ----------
        F: CPnts_RealFunction
        D: Standard_Address
        Order: int

        Returns
        -------
        None
        We want to solve integral(x0,x,f(x,d)) = l.

        Parameters
        ----------
        X0: float
        L: float

        Returns
        -------
        None
        We want to solve integral(x0,x,f(x,d)) = l with given tolerance.

        Parameters
        ----------
        X0: float
        L: float
        Tol: float

        Returns
        -------
        None

        """
        return _CPnts.CPnts_MyRootFunction_Init(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _CPnts.delete_CPnts_MyRootFunction

# Register CPnts_MyRootFunction in _CPnts:
_CPnts.CPnts_MyRootFunction_swigregister(CPnts_MyRootFunction)

class CPnts_UniformDeflection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creation of a indefinite uniformdeflection.

        Returns
        -------
        None
        Computes a uniform deflection distribution of points on the curve <c>. <deflection> defines the constant deflection value. the algorithm computes the number of points and the points. the curve <c> must be at least c2 else the computation can fail. if just some parts of the curve is c2 it is better to give the parameters bounds and to use the below constructor . if <withcontrol> is true, the algorithm controls the estimate deflection when the curve is singular at the point p(u),the algorithm computes the next point as p(u + max(currentstep,abs(lastparameter-firstparameter))) if the singularity is at the first point ,the next point calculated is the p(lastparameter).

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        Resolution: float
        WithControl: bool

        Returns
        -------
        None
        As above with 2d curve.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        Resolution: float
        WithControl: bool

        Returns
        -------
        None
        Computes an uniform deflection distribution of points on a part of the curve <c>. deflection defines the step between the points. <u1> and <u2> define the distribution span. <u1> and <u2> must be in the parametric range of the curve.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        U1: float
        U2: float
        Resolution: float
        WithControl: bool

        Returns
        -------
        None
        As above with 2d curve.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        U1: float
        U2: float
        Resolution: float
        WithControl: bool

        Returns
        -------
        None

        """
        _CPnts.CPnts_UniformDeflection_swiginit(self, _CPnts.new_CPnts_UniformDeflection(*args))

    def Initialize(self, *args) -> "void":
        r"""
        Initialize the algoritms with <c>, <deflection>, <ustep>, <resolution> and <withcontrol>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        Resolution: float
        WithControl: bool

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>, <ustep>, <resolution> and <withcontrol>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        Resolution: float
        WithControl: bool

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>, <ustep>, <u1>, <u2> and <withcontrol>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        U1: float
        U2: float
        Resolution: float
        WithControl: bool

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>, <ustep>, <u1>, <u2> and <withcontrol>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        U1: float
        U2: float
        Resolution: float
        WithControl: bool

        Returns
        -------
        None

        """
        return _CPnts.CPnts_UniformDeflection_Initialize(self, *args)

    def IsAllDone(self, *args) -> "Standard_Boolean":
        r"""
        To know if all the calculus were done successfully (ie all the points have been computed). the calculus can fail if the curve is not c1 in the considered domain. returns true if the calculus was successful.

        Returns
        -------
        bool

        """
        return _CPnts.CPnts_UniformDeflection_IsAllDone(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if it exists a next point.

        Returns
        -------
        bool

        """
        return _CPnts.CPnts_UniformDeflection_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        Go to the next point.

        Returns
        -------
        None

        """
        return _CPnts.CPnts_UniformDeflection_Next(self, *args)

    def Point(self, *args) -> "gp_Pnt":
        r"""
        Return the computed parameter.

        Returns
        -------
        gp_Pnt

        """
        return _CPnts.CPnts_UniformDeflection_Point(self, *args)

    def Value(self, *args) -> "Standard_Real":
        r"""
        Return the computed parameter.

        Returns
        -------
        float

        """
        return _CPnts.CPnts_UniformDeflection_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _CPnts.delete_CPnts_UniformDeflection

# Register CPnts_UniformDeflection in _CPnts:
_CPnts.CPnts_UniformDeflection_swigregister(CPnts_UniformDeflection)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMDocStd module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmdocstd.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMDocStd
else:
    import _XmlMDocStd

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMDocStd.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMDocStd.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMDocStd.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMDocStd.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMDocStd.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDocStd.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMDocStd.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMDocStd.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMDocStd.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMDocStd.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMDocStd.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDocStd.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDocStd.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMDocStd.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMDocStd.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMDocStd.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMDocStd.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMDocStd:
_XmlMDocStd.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMDocStd.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMDocStd_XLinkDriver_Create() -> "opencascade::handle< XmlMDocStd_XLinkDriver >":
    return _XmlMDocStd.Handle_XmlMDocStd_XLinkDriver_Create()

def Handle_XmlMDocStd_XLinkDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDocStd_XLinkDriver >":
    return _XmlMDocStd.Handle_XmlMDocStd_XLinkDriver_DownCast(t)

def Handle_XmlMDocStd_XLinkDriver_IsNull(t: "opencascade::handle< XmlMDocStd_XLinkDriver > const &") -> "bool":
    return _XmlMDocStd.Handle_XmlMDocStd_XLinkDriver_IsNull(t)
class xmlmdocstd(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMDocStd.xmlmdocstd_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMDocStd.xmlmdocstd_swiginit(self, _XmlMDocStd.new_xmlmdocstd())
    __swig_destroy__ = _XmlMDocStd.delete_xmlmdocstd

# Register xmlmdocstd in _XmlMDocStd:
_XmlMDocStd.xmlmdocstd_swigregister(xmlmdocstd)

def xmlmdocstd_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    theMessageDriver: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMDocStd.xmlmdocstd_AddDrivers(*args)

class XmlMDocStd_XLinkDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDocStd.XmlMDocStd_XLinkDriver_swiginit(self, _XmlMDocStd.new_XmlMDocStd_XLinkDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDocStd.XmlMDocStd_XLinkDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDocStd_XLinkDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDocStd.delete_XmlMDocStd_XLinkDriver

# Register XmlMDocStd_XLinkDriver in _XmlMDocStd:
_XmlMDocStd.XmlMDocStd_XLinkDriver_swigregister(XmlMDocStd_XLinkDriver)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *


class Image_CompressedFormat(IntEnum):
	Image_CompressedFormat_UNKNOWN: int = ...
	Image_CompressedFormat_RGB_S3TC_DXT1: int = ...
	Image_CompressedFormat_RGBA_S3TC_DXT1: int = ...
	Image_CompressedFormat_RGBA_S3TC_DXT3: int = ...
	Image_CompressedFormat_RGBA_S3TC_DXT5: int = ...
Image_CompressedFormat_UNKNOWN = Image_CompressedFormat.Image_CompressedFormat_UNKNOWN
Image_CompressedFormat_RGB_S3TC_DXT1 = Image_CompressedFormat.Image_CompressedFormat_RGB_S3TC_DXT1
Image_CompressedFormat_RGBA_S3TC_DXT1 = Image_CompressedFormat.Image_CompressedFormat_RGBA_S3TC_DXT1
Image_CompressedFormat_RGBA_S3TC_DXT3 = Image_CompressedFormat.Image_CompressedFormat_RGBA_S3TC_DXT3
Image_CompressedFormat_RGBA_S3TC_DXT5 = Image_CompressedFormat.Image_CompressedFormat_RGBA_S3TC_DXT5

class Image_Format(IntEnum):
	Image_Format_UNKNOWN: int = ...
	Image_Format_Gray: int = ...
	Image_Format_Alpha: int = ...
	Image_Format_RGB: int = ...
	Image_Format_BGR: int = ...
	Image_Format_RGB32: int = ...
	Image_Format_BGR32: int = ...
	Image_Format_RGBA: int = ...
	Image_Format_BGRA: int = ...
	Image_Format_GrayF: int = ...
	Image_Format_AlphaF: int = ...
	Image_Format_RGF: int = ...
	Image_Format_RGBF: int = ...
	Image_Format_BGRF: int = ...
	Image_Format_RGBAF: int = ...
	Image_Format_BGRAF: int = ...
Image_Format_UNKNOWN = Image_Format.Image_Format_UNKNOWN
Image_Format_Gray = Image_Format.Image_Format_Gray
Image_Format_Alpha = Image_Format.Image_Format_Alpha
Image_Format_RGB = Image_Format.Image_Format_RGB
Image_Format_BGR = Image_Format.Image_Format_BGR
Image_Format_RGB32 = Image_Format.Image_Format_RGB32
Image_Format_BGR32 = Image_Format.Image_Format_BGR32
Image_Format_RGBA = Image_Format.Image_Format_RGBA
Image_Format_BGRA = Image_Format.Image_Format_BGRA
Image_Format_GrayF = Image_Format.Image_Format_GrayF
Image_Format_AlphaF = Image_Format.Image_Format_AlphaF
Image_Format_RGF = Image_Format.Image_Format_RGF
Image_Format_RGBF = Image_Format.Image_Format_RGBF
Image_Format_BGRF = Image_Format.Image_Format_BGRF
Image_Format_RGBAF = Image_Format.Image_Format_RGBAF
Image_Format_BGRAF = Image_Format.Image_Format_BGRAF

#classnotwrapped
class Image_ColorRGB: ...

#classnotwrapped
class Image_ColorRGB32: ...

#classnotwrapped
class Image_ColorRGBA: ...

#classnotwrapped
class Image_ColorBGR: ...

#classnotwrapped
class Image_ColorBGR32: ...

#classnotwrapped
class Image_ColorBGRA: ...

#classnotwrapped
class Image_ColorRGF: ...

#classnotwrapped
class Image_ColorRGBF: ...

#classnotwrapped
class Image_ColorBGRF: ...

#classnotwrapped
class Image_ColorRGBAF: ...

#classnotwrapped
class Image_ColorBGRAF: ...

#classnotwrapped
class Image_VideoParams: ...

#classnotwrapped
class Image_VideoRecorder: ...

#classnotwrapped
class Image_CompressedPixMap: ...

#classnotwrapped
class Image_PixMapData: ...

#classnotwrapped
class Image_PixMapTypedData: ...

#classnotwrapped
class Image_DDSParser: ...

#classnotwrapped
class Image_PixMap: ...

#classnotwrapped
class Image_Texture: ...

#classnotwrapped
class Image_AlienPixMap: ...

#classnotwrapped
class Image_Diff: ...

#classnotwrapped
class Image_SupportedFormats: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepPrimAPI module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepprimapi.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepPrimAPI
else:
    import _BRepPrimAPI

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepPrimAPI.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepPrimAPI.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepPrimAPI.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepPrimAPI.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepPrimAPI.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepPrimAPI.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepPrimAPI.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepPrimAPI.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepPrimAPI.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepPrimAPI.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepPrimAPI.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepPrimAPI.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepPrimAPI.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepPrimAPI.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepPrimAPI.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepPrimAPI.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepPrimAPI.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepPrimAPI:
_BRepPrimAPI.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepPrimAPI.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BRepBuilderAPI
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.TopTools
import OCC.Core.BRepTools
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.Geom2d
import OCC.Core.BRep
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.BRepPrim
import OCC.Core.BRepSweep
import OCC.Core.Sweep

from enum import IntEnum
from OCC.Core.Exception import *



class BRepPrimAPI_MakeBox(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None
        Make a box with a corner at 0,0,0 and the other dx,dy,dz.

        Parameters
        ----------
        dx: float
        dy: float
        dz: float

        Returns
        -------
        None
        Make a box with a corner at p and size dx, dy, dz.

        Parameters
        ----------
        P: gp_Pnt
        dx: float
        dy: float
        dz: float

        Returns
        -------
        None
        Make a box with corners p1,p2.

        Parameters
        ----------
        P1: gp_Pnt
        P2: gp_Pnt

        Returns
        -------
        None
        Make a box with ax2 (the left corner and the axis) and size dx, dy, dz.

        Parameters
        ----------
        Axes: gp_Ax2
        dx: float
        dy: float
        dz: float

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeBox_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeBox(*args))

    def BackFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns xmin face.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_BackFace(self, *args)

    def BottomFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns zmin face.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_BottomFace(self, *args)

    def FrontFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns xmax face.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_FrontFace(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Init a box with a corner at 0,0,0 and the other thedx, thedy, thedz.

        Parameters
        ----------
        theDX: float
        theDY: float
        theDZ: float

        Returns
        -------
        None
        Init a box with a corner at thepnt and size thedx, thedy, thedz.

        Parameters
        ----------
        thePnt: gp_Pnt
        theDX: float
        theDY: float
        theDZ: float

        Returns
        -------
        None
        Init a box with corners thepnt1, thepnt2.

        Parameters
        ----------
        thePnt1: gp_Pnt
        thePnt2: gp_Pnt

        Returns
        -------
        None
        Init a box with ax2 (the left corner and the theaxes) and size thedx, thedy, thedz.

        Parameters
        ----------
        theAxes: gp_Ax2
        theDX: float
        theDY: float
        theDZ: float

        Returns
        -------
        None

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_Init(self, *args)

    def LeftFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns ymin face.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_LeftFace(self, *args)

    def RightFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns ymax face.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_RightFace(self, *args)

    def Shell(self, *args) -> "TopoDS_Shell const":
        r"""
        Returns the constructed box as a shell.

        Returns
        -------
        TopoDS_Shell

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_Shell(self, *args)

    def Solid(self, *args) -> "TopoDS_Solid const":
        r"""
        Returns the constructed box as a solid.

        Returns
        -------
        TopoDS_Solid

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_Solid(self, *args)

    def TopFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns zmax face.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_TopFace(self, *args)

    def Wedge(self, *args) -> "BRepPrim_Wedge &":
        r"""
        Returns the internal algorithm.

        Returns
        -------
        BRepPrim_Wedge

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeBox_Wedge(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeBox

# Register BRepPrimAPI_MakeBox in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeBox_swigregister(BRepPrimAPI_MakeBox)

class BRepPrimAPI_MakeHalfSpace(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make a halfspace defined with a face and a point.

        Parameters
        ----------
        Face: TopoDS_Face
        RefPnt: gp_Pnt

        Returns
        -------
        None
        Make a halfspace defined with a shell and a point.

        Parameters
        ----------
        Shell: TopoDS_Shell
        RefPnt: gp_Pnt

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeHalfSpace_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeHalfSpace(*args))

    def Solid(self, *args) -> "TopoDS_Solid const":
        r"""
        Returns the constructed half-space as a solid.

        Returns
        -------
        TopoDS_Solid

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeHalfSpace_Solid(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeHalfSpace

# Register BRepPrimAPI_MakeHalfSpace in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeHalfSpace_swigregister(BRepPrimAPI_MakeHalfSpace)

class BRepPrimAPI_MakeOneAxis(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Face(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the lateral face of the rotational primitive.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeOneAxis_Face(self, *args)

    def OneAxis(self, *args) -> "Standard_Address":
        r"""
        The inherited commands should provide the algorithm. returned as a pointer.

        Returns
        -------
        Standard_Address

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeOneAxis_OneAxis(self, *args)

    def Shell(self, *args) -> "TopoDS_Shell const":
        r"""
        Returns the constructed rotational primitive as a shell.

        Returns
        -------
        TopoDS_Shell

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeOneAxis_Shell(self, *args)

    def Solid(self, *args) -> "TopoDS_Solid const":
        r"""
        Returns the constructed rotational primitive as a solid.

        Returns
        -------
        TopoDS_Solid

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeOneAxis_Solid(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeOneAxis

# Register BRepPrimAPI_MakeOneAxis in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeOneAxis_swigregister(BRepPrimAPI_MakeOneAxis)

class BRepPrimAPI_MakeSweep(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def FirstShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape of the bottom of the sweep.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeSweep_FirstShape(self, *args)

    def LastShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape of the top of the sweep.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeSweep_LastShape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeSweep

# Register BRepPrimAPI_MakeSweep in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeSweep_swigregister(BRepPrimAPI_MakeSweep)

class BRepPrimAPI_MakeWedge(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make a step right angular wedge. (ltx >= 0).

        Parameters
        ----------
        dx: float
        dy: float
        dz: float
        ltx: float

        Returns
        -------
        None
        Make a step right angular wedge. (ltx >= 0).

        Parameters
        ----------
        Axes: gp_Ax2
        dx: float
        dy: float
        dz: float
        ltx: float

        Returns
        -------
        None
        Make a wedge. the face at dy is xmin,zmin xmax,zmax.

        Parameters
        ----------
        dx: float
        dy: float
        dz: float
        xmin: float
        zmin: float
        xmax: float
        zmax: float

        Returns
        -------
        None
        Make a wedge. the face at dy is xmin,zmin xmax,zmax.

        Parameters
        ----------
        Axes: gp_Ax2
        dx: float
        dy: float
        dz: float
        xmin: float
        zmin: float
        xmax: float
        zmax: float

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeWedge_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeWedge(*args))

    def Shell(self, *args) -> "TopoDS_Shell const":
        r"""
        Returns the constructed box in the form of a shell.

        Returns
        -------
        TopoDS_Shell

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeWedge_Shell(self, *args)

    def Solid(self, *args) -> "TopoDS_Solid const":
        r"""
        Returns the constructed box in the form of a solid.

        Returns
        -------
        TopoDS_Solid

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeWedge_Solid(self, *args)

    def Wedge(self, *args) -> "BRepPrim_Wedge &":
        r"""
        Returns the internal algorithm.

        Returns
        -------
        BRepPrim_Wedge

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeWedge_Wedge(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeWedge

# Register BRepPrimAPI_MakeWedge in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeWedge_swigregister(BRepPrimAPI_MakeWedge)

class BRepPrimAPI_MakeCone(BRepPrimAPI_MakeOneAxis):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make a cone. @param r1 [in] cone bottom radius, may be null (z = 0) @param r2 [in] cone top radius, may be null (z = h) @param h [in] cone height.

        Parameters
        ----------
        R1: float
        R2: float
        H: float

        Returns
        -------
        None
        Make a cone. @param r1 [in] cone bottom radius, may be null (z = 0) @param r2 [in] cone top radius, may be null (z = h) @param h [in] cone height @param angle [in] angle to create a part cone.

        Parameters
        ----------
        R1: float
        R2: float
        H: float
        angle: float

        Returns
        -------
        None
        Make a cone. @param axes [in] coordinate system for the construction of the cone @param r1 [in] cone bottom radius, may be null (z = 0) @param r2 [in] cone top radius, may be null (z = h) @param h [in] cone height.

        Parameters
        ----------
        Axes: gp_Ax2
        R1: float
        R2: float
        H: float

        Returns
        -------
        None
        Make a cone of height h radius r1 in the plane z = 0, r2 in the plane z = h. r1 and r2 may be null. take a section of <angle> constructs a cone, or a portion of a cone, of height h, and radius r1 in the plane z = 0 and r2 in the plane z = h. the result is a sharp cone if r1 or r2 is equal to 0. the cone is constructed about the 'z axis' of either: - the global coordinate system, or - the local coordinate system axes. it is limited in these coordinate systems as follows: - in the v parametric direction (the z coordinate), by the two parameter values 0 and h, - and in the u parametric direction (defined by the angle of rotation around the z axis), in the case of a portion of a cone, by the two parameter values 0 and angle. angle is given in radians. the resulting shape is composed of: - a lateral conical face - two planar faces in the planes z = 0 and z = h, or only one planar face in one of these two planes if a radius value is null (in the case of a complete cone, these faces are circles), and - and in the case of a portion of a cone, two planar faces to close the shape. (either two parallelograms or two triangles, in the planes u = 0 and u = angle). exceptions standard_domainerror if: - h is less than or equal to precision::confusion(), or - the half-angle at the apex of the cone, defined by r1, r2 and h, is less than precision::confusion()/h, or greater than (pi/2)-precision::confusion()/h.f.

        Parameters
        ----------
        Axes: gp_Ax2
        R1: float
        R2: float
        H: float
        angle: float

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeCone_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeCone(*args))

    def Cone(self, *args) -> "BRepPrim_Cone &":
        r"""
        Returns the algorithm.

        Returns
        -------
        BRepPrim_Cone

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeCone_Cone(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeCone

# Register BRepPrimAPI_MakeCone in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeCone_swigregister(BRepPrimAPI_MakeCone)

class BRepPrimAPI_MakeCylinder(BRepPrimAPI_MakeOneAxis):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make a cylinder. @param r [in] cylinder radius @param h [in] cylinder height.

        Parameters
        ----------
        R: float
        H: float

        Returns
        -------
        None
        Make a cylinder (part cylinder). @param r [in] cylinder radius @param h [in] cylinder height @param angle [in] defines the missing portion of the cylinder.

        Parameters
        ----------
        R: float
        H: float
        Angle: float

        Returns
        -------
        None
        Make a cylinder of radius r and length h. @param axes [in] coordinate system for the construction of the cylinder @param r [in] cylinder radius @param h [in] cylinder height.

        Parameters
        ----------
        Axes: gp_Ax2
        R: float
        H: float

        Returns
        -------
        None
        Make a cylinder of radius r and length h with angle h. constructs - a cylinder of radius r and height h, or - a portion of cylinder of radius r and height h, and of the angle angle defining the missing portion of the cylinder. the cylinder is constructed about the 'z axis' of either: - the global coordinate system, or - the local coordinate system axes. it is limited in this coordinate system as follows: - in the v parametric direction (the z axis), by the two parameter values 0 and h, - and in the u parametric direction (the rotation angle around the z axis), in the case of a portion of a cylinder, by the two parameter values 0 and angle. angle is given in radians. the resulting shape is composed of: - a lateral cylindrical face, - two planar faces in the planes z = 0 and z = h (in the case of a complete cylinder, these faces are circles), and - in case of a portion of a cylinder, two additional planar faces to close the shape.(two rectangles in the planes u = 0 and u = angle). exceptions standard_domainerror if: - r is less than or equal to precision::confusion(), or - h is less than or equal to precision::confusion().

        Parameters
        ----------
        Axes: gp_Ax2
        R: float
        H: float
        Angle: float

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeCylinder_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeCylinder(*args))

    def Cylinder(self, *args) -> "BRepPrim_Cylinder &":
        r"""
        Returns the algorithm.

        Returns
        -------
        BRepPrim_Cylinder

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeCylinder_Cylinder(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeCylinder

# Register BRepPrimAPI_MakeCylinder in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeCylinder_swigregister(BRepPrimAPI_MakeCylinder)

class BRepPrimAPI_MakePrism(BRepPrimAPI_MakeSweep):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Builds the prism of base s and vector v. if c is true, s is copied. if canonize is true then generated surfaces are attempted to be canonized in simple types.

        Parameters
        ----------
        S: TopoDS_Shape
        V: gp_Vec
        Copy: bool,optional
        	default value is Standard_False
        Canonize: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Builds a semi-infinite or an infinite prism of base s. if inf is true the prism is infinite, if inf is false the prism is semi-infinite (in the direction d). if c is true s is copied (for semi-infinite prisms). if canonize is true then generated surfaces are attempted to be canonized in simple types.

        Parameters
        ----------
        S: TopoDS_Shape
        D: gp_Dir
        Inf: bool,optional
        	default value is Standard_True
        Copy: bool,optional
        	default value is Standard_False
        Canonize: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakePrism_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakePrism(*args))

    def FirstShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape of the bottom of the prism.

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape of the bottom of the prism. generated with theshape (subshape of the generating shape).

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepPrimAPI.BRepPrimAPI_MakePrism_FirstShape(self, *args)

    def LastShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape of the top of the prism. in the case of a finite prism, firstshape returns the basis of the prism, in other words, s if copy is false; otherwise, the copy of s belonging to the prism. lastshape returns the copy of s translated by v at the time of construction.

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape of the top of the prism. generated with theshape (subshape of the generating shape).

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepPrimAPI.BRepPrimAPI_MakePrism_LastShape(self, *args)

    def Prism(self, *args) -> "BRepSweep_Prism const &":
        r"""
        Returns the internal sweeping algorithm.

        Returns
        -------
        BRepSweep_Prism

        """
        return _BRepPrimAPI.BRepPrimAPI_MakePrism_Prism(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakePrism

# Register BRepPrimAPI_MakePrism in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakePrism_swigregister(BRepPrimAPI_MakePrism)

class BRepPrimAPI_MakeRevol(BRepPrimAPI_MakeSweep):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Builds the revol of base s, axis a and angle d. if c is true, s is copied.

        Parameters
        ----------
        S: TopoDS_Shape
        A: gp_Ax1
        D: float
        Copy: bool,optional
        	default value is Standard_False

        Returns
        -------
        None
        Builds the revol of base s, axis a and angle 2*pi. if c is true, s is copied.

        Parameters
        ----------
        S: TopoDS_Shape
        A: gp_Ax1
        Copy: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeRevol_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeRevol(*args))

    def Degenerated(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of degenerated edges.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeRevol_Degenerated(self, *args)

    def FirstShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the first shape of the revol (coinciding with the generating shape).

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape of the beginning of the revolution, generated with theshape (subshape of the generating shape).

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeRevol_FirstShape(self, *args)

    def HasDegenerated(self, *args) -> "Standard_Boolean":
        r"""
        Check if there are degenerated edges in the result.

        Returns
        -------
        bool

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeRevol_HasDegenerated(self, *args)

    def LastShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the topods shape of the end of the revol.

        Returns
        -------
        TopoDS_Shape
        Returns the topods shape of the end of the revolution, generated with theshape (subshape of the generating shape).

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeRevol_LastShape(self, *args)

    def Revol(self, *args) -> "BRepSweep_Revol const &":
        r"""
        Returns the internal sweeping algorithm.

        Returns
        -------
        BRepSweep_Revol

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeRevol_Revol(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeRevol

# Register BRepPrimAPI_MakeRevol in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeRevol_swigregister(BRepPrimAPI_MakeRevol)

class BRepPrimAPI_MakeRevolution(BRepPrimAPI_MakeOneAxis):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make a revolution body by rotating a curve around z.

        Parameters
        ----------
        Meridian: Geom_Curve

        Returns
        -------
        None
        Make a revolution body by rotating a curve around z.

        Parameters
        ----------
        Meridian: Geom_Curve
        angle: float

        Returns
        -------
        None
        Make a revolution body by rotating a curve around z.

        Parameters
        ----------
        Meridian: Geom_Curve
        VMin: float
        VMax: float

        Returns
        -------
        None
        Make a revolution body by rotating a curve around z.

        Parameters
        ----------
        Meridian: Geom_Curve
        VMin: float
        VMax: float
        angle: float

        Returns
        -------
        None
        Make a revolution body by rotating a curve around z.

        Parameters
        ----------
        Axes: gp_Ax2
        Meridian: Geom_Curve

        Returns
        -------
        None
        Make a revolution body by rotating a curve around z.

        Parameters
        ----------
        Axes: gp_Ax2
        Meridian: Geom_Curve
        angle: float

        Returns
        -------
        None
        Make a revolution body by rotating a curve around z.

        Parameters
        ----------
        Axes: gp_Ax2
        Meridian: Geom_Curve
        VMin: float
        VMax: float

        Returns
        -------
        None
        Make a revolution body by rotating a curve around z. for all algorithms the resulting shape is composed of - a lateral revolved face, - two planar faces in planes parallel to the plane z = 0, and passing by the extremities of the revolved portion of meridian, if these points are not on the z axis (in case of a complete revolved shape, these faces are circles), - and in the case of a portion of a revolved shape, two planar faces to close the shape (in the planes u = 0 and u = angle).

        Parameters
        ----------
        Axes: gp_Ax2
        Meridian: Geom_Curve
        VMin: float
        VMax: float
        angle: float

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeRevolution_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeRevolution(*args))

    def Revolution(self, *args) -> "BRepPrim_Revolution &":
        r"""
        Returns the algorithm.

        Returns
        -------
        BRepPrim_Revolution

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeRevolution_Revolution(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeRevolution

# Register BRepPrimAPI_MakeRevolution in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeRevolution_swigregister(BRepPrimAPI_MakeRevolution)

class BRepPrimAPI_MakeSphere(BRepPrimAPI_MakeOneAxis):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make a sphere. @param r [in] sphere radius.

        Parameters
        ----------
        R: float

        Returns
        -------
        None
        Make a sphere (spherical wedge). @param r [in] sphere radius @param angle [in] angle between the radii lying within the bounding semidisks.

        Parameters
        ----------
        R: float
        angle: float

        Returns
        -------
        None
        Make a sphere (spherical segment). @param r [in] sphere radius @param angle1 [in] first angle defining a spherical segment @param angle2 [in] second angle defining a spherical segment.

        Parameters
        ----------
        R: float
        angle1: float
        angle2: float

        Returns
        -------
        None
        Make a sphere (spherical segment). @param r [in] sphere radius @param angle1 [in] first angle defining a spherical segment @param angle2 [in] second angle defining a spherical segment @param angle3 [in] angle between the radii lying within the bounding semidisks.

        Parameters
        ----------
        R: float
        angle1: float
        angle2: float
        angle3: float

        Returns
        -------
        None
        Make a sphere. @param center [in] sphere center coordinates @param r [in] sphere radius.

        Parameters
        ----------
        Center: gp_Pnt
        R: float

        Returns
        -------
        None
        Make a sphere (spherical wedge). @param center [in] sphere center coordinates @param r [in] sphere radius @param angle [in] angle between the radii lying within the bounding semidisks.

        Parameters
        ----------
        Center: gp_Pnt
        R: float
        angle: float

        Returns
        -------
        None
        Make a sphere (spherical segment). @param center [in] sphere center coordinates @param r [in] sphere radius @param angle1 [in] first angle defining a spherical segment @param angle2 [in] second angle defining a spherical segment.

        Parameters
        ----------
        Center: gp_Pnt
        R: float
        angle1: float
        angle2: float

        Returns
        -------
        None
        Make a sphere (spherical segment). @param center [in] sphere center coordinates @param r [in] sphere radius @param angle1 [in] first angle defining a spherical segment @param angle2 [in] second angle defining a spherical segment @param angle3 [in] angle between the radii lying within the bounding semidisks.

        Parameters
        ----------
        Center: gp_Pnt
        R: float
        angle1: float
        angle2: float
        angle3: float

        Returns
        -------
        None
        Make a sphere. @param axis [in] coordinate system for the construction of the sphere @param r [in] sphere radius.

        Parameters
        ----------
        Axis: gp_Ax2
        R: float

        Returns
        -------
        None
        Make a sphere (spherical wedge). @param axis [in] coordinate system for the construction of the sphere @param r [in] sphere radius @param angle [in] angle between the radii lying within the bounding semidisks.

        Parameters
        ----------
        Axis: gp_Ax2
        R: float
        angle: float

        Returns
        -------
        None
        Make a sphere (spherical segment). @param axis [in] coordinate system for the construction of the sphere @param r [in] sphere radius @param angle1 [in] first angle defining a spherical segment @param angle2 [in] second angle defining a spherical segment.

        Parameters
        ----------
        Axis: gp_Ax2
        R: float
        angle1: float
        angle2: float

        Returns
        -------
        None
        Make a sphere of radius r. for all algorithms the resulting shape is composed of - a lateral spherical face, - two planar faces parallel to the plane z = 0 if the sphere is truncated in the v parametric direction, or only one planar face if angle1 is equal to -p/2 or if angle2 is equal to p/2 (these faces are circles in case of a complete truncated sphere), - and in case of a portion of sphere, two planar faces to shut the shape.(in the planes u = 0 and u = angle).

        Parameters
        ----------
        Axis: gp_Ax2
        R: float
        angle1: float
        angle2: float
        angle3: float

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeSphere_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeSphere(*args))

    def Sphere(self, *args) -> "BRepPrim_Sphere &":
        r"""
        Returns the algorithm.

        Returns
        -------
        BRepPrim_Sphere

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeSphere_Sphere(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeSphere

# Register BRepPrimAPI_MakeSphere in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeSphere_swigregister(BRepPrimAPI_MakeSphere)

class BRepPrimAPI_MakeTorus(BRepPrimAPI_MakeOneAxis):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make a torus. @param r1 [in] distance from the center of the pipe to the center of the torus @param r2 [in] radius of the pipe.

        Parameters
        ----------
        R1: float
        R2: float

        Returns
        -------
        None
        Make a section of a torus. @param r1 [in] distance from the center of the pipe to the center of the torus @param r2 [in] radius of the pipe @param angle [in] angle to create a torus pipe segment.

        Parameters
        ----------
        R1: float
        R2: float
        angle: float

        Returns
        -------
        None
        Make a torus with angles on the small circle. @param r1 [in] distance from the center of the pipe to the center of the torus @param r2 [in] radius of the pipe @param angle1 [in] first angle to create a torus ring segment @param angle2 [in] second angle to create a torus ring segment.

        Parameters
        ----------
        R1: float
        R2: float
        angle1: float
        angle2: float

        Returns
        -------
        None
        Make a torus with angles on the small circle. @param r1 [in] distance from the center of the pipe to the center of the torus @param r2 [in] radius of the pipe @param angle1 [in] first angle to create a torus ring segment @param angle2 [in] second angle to create a torus ring segment @param angle [in] angle to create a torus pipe segment.

        Parameters
        ----------
        R1: float
        R2: float
        angle1: float
        angle2: float
        angle: float

        Returns
        -------
        None
        Make a torus. @param axes [in] coordinate system for the construction of the sphere @param r1 [in] distance from the center of the pipe to the center of the torus @param r2 [in] radius of the pipe.

        Parameters
        ----------
        Axes: gp_Ax2
        R1: float
        R2: float

        Returns
        -------
        None
        Make a section of a torus. @param axes [in] coordinate system for the construction of the sphere @param r1 [in] distance from the center of the pipe to the center of the torus @param r2 [in] radius of the pipe @param angle [in] angle to create a torus pipe segment.

        Parameters
        ----------
        Axes: gp_Ax2
        R1: float
        R2: float
        angle: float

        Returns
        -------
        None
        Make a torus. @param axes [in] coordinate system for the construction of the sphere @param r1 [in] distance from the center of the pipe to the center of the torus @param r2 [in] radius of the pipe @param angle1 [in] first angle to create a torus ring segment @param angle2 [in] second angle to create a torus ring segment.

        Parameters
        ----------
        Axes: gp_Ax2
        R1: float
        R2: float
        angle1: float
        angle2: float

        Returns
        -------
        None
        Make a section of a torus of radii r1 r2. for all algorithms the resulting shape is composed of - a lateral toroidal face, - two conical faces (defined by the equation v = angle1 and v = angle2) if the sphere is truncated in the v parametric direction (they may be cylindrical faces in some particular conditions), and in case of a portion of torus, two planar faces to close the shape.(in the planes u = 0 and u = angle). notes: - the u parameter corresponds to a rotation angle around the z axis. - the circle whose radius is equal to the minor radius, located in the plane defined by the x axis and the z axis, centered on the x axis, on its positive side, and positioned at a distance from the origin equal to the major radius, is the reference circle of the torus. the rotation around an axis parallel to the y axis and passing through the center of the reference circle gives the v parameter on the reference circle. the x axis gives the origin of the v parameter. near 0, as v increases, the z coordinate decreases.

        Parameters
        ----------
        Axes: gp_Ax2
        R1: float
        R2: float
        angle1: float
        angle2: float
        angle: float

        Returns
        -------
        None

        """
        _BRepPrimAPI.BRepPrimAPI_MakeTorus_swiginit(self, _BRepPrimAPI.new_BRepPrimAPI_MakeTorus(*args))

    def Torus(self, *args) -> "BRepPrim_Torus &":
        r"""
        Returns the algorithm.

        Returns
        -------
        BRepPrim_Torus

        """
        return _BRepPrimAPI.BRepPrimAPI_MakeTorus_Torus(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrimAPI.delete_BRepPrimAPI_MakeTorus

# Register BRepPrimAPI_MakeTorus in _BRepPrimAPI:
_BRepPrimAPI.BRepPrimAPI_MakeTorus_swigregister(BRepPrimAPI_MakeTorus)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.Bnd import *
from OCC.Core.gp import *
from OCC.Core.TopAbs import *
from OCC.Core.Adaptor3d import *
from OCC.Core.GeomAbs import *
from OCC.Core.IntCurveSurface import *


class IntCurvesFace_Intersector:
	def __init__(self, F: TopoDS_Face, aTol: float, aRestr: Optional[bool] = True, UseBToler: Optional[bool] = True) -> None: ...
	def Bounding(self) -> Bnd_Box: ...
	def ClassifyUVPoint(self, Puv: gp_Pnt2d) -> TopAbs_State: ...
	def Destroy(self) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def GetUseBoundToler(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def IsParallel(self) -> bool: ...
	def NbPnt(self) -> int: ...
	@overload
	def Perform(self, L: gp_Lin, PInf: float, PSup: float) -> None: ...
	@overload
	def Perform(self, HCu: Adaptor3d_HCurve, PInf: float, PSup: float) -> None: ...
	def Pnt(self, I: int) -> gp_Pnt: ...
	def SetUseBoundToler(self, UseBToler: bool) -> None: ...
	def State(self, I: int) -> TopAbs_State: ...
	def SurfaceType(self) -> GeomAbs_SurfaceType: ...
	def Transition(self, I: int) -> IntCurveSurface_TransitionOnCurve: ...
	def UParameter(self, I: int) -> float: ...
	def VParameter(self, I: int) -> float: ...
	def WParameter(self, I: int) -> float: ...

class IntCurvesFace_ShapeIntersector:
	def __init__(self) -> None: ...
	def Destroy(self) -> None: ...
	def Face(self, I: int) -> TopoDS_Face: ...
	def IsDone(self) -> bool: ...
	def Load(self, Sh: TopoDS_Shape, Tol: float) -> None: ...
	def NbPnt(self) -> int: ...
	@overload
	def Perform(self, L: gp_Lin, PInf: float, PSup: float) -> None: ...
	@overload
	def Perform(self, HCu: Adaptor3d_HCurve, PInf: float, PSup: float) -> None: ...
	def PerformNearest(self, L: gp_Lin, PInf: float, PSup: float) -> None: ...
	def Pnt(self, I: int) -> gp_Pnt: ...
	def SortResult(self) -> None: ...
	def State(self, I: int) -> TopAbs_State: ...
	def Transition(self, I: int) -> IntCurveSurface_TransitionOnCurve: ...
	def UParameter(self, I: int) -> float: ...
	def VParameter(self, I: int) -> float: ...
	def WParameter(self, I: int) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes

